Sviluppo — SoL 4, manuale utente

# Sviluppo

Lo sviluppo di SoL avviene in un repository git ospitato da GitLab, che viene automaticamente sincronizzato su Bitbucket.

Puoi visitare la pagina con l'attività per vedere cosa è stato fatto di recente.

Se sei uno sviluppatore, sei incoraggiato a creare un fork per adattare e migliorare SoL e sarò più che contento di integrare le modifiche che potrai contribuire.

In alternativa puoi tradurlo in un'altra lingua, usando il servizio online di Weblate.

C'è anche una documentazione tecnica estratta automaticamente dai sorgenti.

## Donazioni

Da sempre1 ho sostenuto tutte le spese di mantenimento di SoL, sia in termini di studio e sviluppo del software, sia per quanto riguarda il costo di hosting del servizio, usabile e consultabile gratuitamente.

Da qualche tempo la ECC sponsorizza lo sviluppo di SoL, sostenendone parte delle spese vive di gestione del server.

Se usi SoL per organizzare tornei, in particolare quelli di rilevanza nazionale, per favore considera la possibilità di fare una donazione contribuendo al suo sviluppo e sostentamento, affinché il servizio possa continuare anche in futuro.

1

  Ho cominciato a scrivere `Scarry` in ottobre del 1999, mentre `SoL` ha visto la luce poco meno di dieci anni più tardi!

### Liberapay

### PayPal